#!/usr/bin/env python3

from pgtoolkit import pgstats, toolbase
from pycolib.ansicolor import highlight, YELLOW, BOLD


class LongQueriesTool(toolbase.SimpleTool):
    def __init__(self):
        toolbase.SimpleTool.__init__(self, name='longqueries', desc='List long queries.')
        self.parser.add_argument('--age', default='1m', help='How long must be the query running to be listed.')
        self.init()

    def main(self):
        stats = pgstats.PgStats(self.pgm.get_conn('target'))

        for ln in stats.list_long_queries(self.args.age):
            print(highlight(1),
                  'backend PID: ', ln['procpid'],
                  ', query_start: ', ln['query_start'].strftime('%F %T'),
                  ', client IP: ', ln['client_addr'],
                  ln['waiting'] and ', ' + highlight(1, YELLOW|BOLD) + 'waiting' or '',
                  highlight(0), sep='')
            print(ln['query'])
            print()


tool = LongQueriesTool()
tool.main()

